@@ -185,12 +185,12 @@ void KateExternalToolsCommand::reload () {
 }
 
 bool KateExternalToolsCommand::exec (Kate::View *view, const TQString &cmd, TQString &) {
-	TQWidget *wv=tqt_dynamic_cast<TQWidget*>(view);
+	TQWidget *wv=dynamic_cast<TQWidget*>(view);
 	if (!wv) {
 // 		kdDebug(13001)<<"KateExternalToolsCommand::exec: Could not get view widget"<<endl;
 		return false;
 	}
-  KateMDI::MainWindow *dmw=tqt_dynamic_cast<KateMDI::MainWindow*>(wv->topLevelWidget());
+  KateMDI::MainWindow *dmw=dynamic_cast<KateMDI::MainWindow*>(wv->topLevelWidget());
 	if (!dmw) {
 // 		kdDebug(13001)<<"KateExternalToolsCommand::exec: Could not get main window"<<endl;
 		return false;
@@ -200,7 +200,7 @@ bool KateExternalToolsCommand::exec (Kate::View *view, const TQString &cmd, TQSt
 	if (actionName.isEmpty()) return false;
 // 	kdDebug(13001)<<"actionName is not empty:"<<actionName<<endl;
 	KateExternalToolsMenuAction *a=
-		tqt_dynamic_cast<KateExternalToolsMenuAction*>(dmw->action("tools_external"));
+		dynamic_cast<KateExternalToolsMenuAction*>(dmw->action("tools_external"));
 	if (!a) return false;
 // 	kdDebug(13001)<<"trying to find action"<<endl;
 	TDEAction *a1=a->actionCollection()->action(static_cast<const char *>(actionName.utf8()));
@@ -225,7 +225,7 @@ KateExternalToolAction::KateExternalToolAction( TQObject *parent,
   if ( ! t->icon.isEmpty() )
     setIconSet( SmallIconSet( t->icon ) );
 
-  connect( this ,TQT_SIGNAL(activated()), this, TQT_SLOT(slotRun()) );
+  connect( this ,TQ_SIGNAL(activated()), this, TQ_SLOT(slotRun()) );
 }
 
 bool KateExternalToolAction::expandMacro( const TQString &str, TQStringList &ret )
@@ -300,7 +300,7 @@ KateExternalToolsMenuAction::KateExternalToolsMenuAction( const TQString &text,
 
   m_actionCollection = new TDEActionCollection( mainwindow );
 
-  connect(KateDocManager::self(),TQT_SIGNAL(documentChanged()),this,TQT_SLOT(slotDocumentChanged()));
+  connect(KateDocManager::self(),TQ_SIGNAL(documentChanged()),this,TQ_SLOT(slotDocumentChanged()));
 
   reload();
 }
@@ -389,7 +389,7 @@ void KateExternalToolsMenuAction::slotDocumentChanged()
     TDEActionPtrList actions = m_actionCollection->actions();
     for (TDEActionPtrList::iterator it = actions.begin(); it != actions.end(); ++it )
     {
-      KateExternalToolAction *action = tqt_dynamic_cast<KateExternalToolAction*>(*it);
+      KateExternalToolAction *action = dynamic_cast<KateExternalToolAction*>(*it);
       if ( action )
       {
         l = action->tool->mimetypes;
@@ -438,7 +438,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
   leName = new TQLineEdit( w );
   lo->addWidget( leName, 1, 2 );
   l = new TQLabel( leName, i18n("&Label:"), w );
-  l->setAlignment( l->alignment()|Qt::AlignRight );
+  l->setAlignment( l->alignment()|TQt::AlignRight );
   lo->addWidget( l, 1, 1 );
   if ( tool ) leName->setText( tool->name );
   TQWhatsThis::add( leName, i18n(
@@ -453,7 +453,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
   teCommand = new TQTextEdit( w );
   lo->addMultiCellWidget( teCommand, 2, 2, 2, 3 );
   l = new TQLabel( teCommand, i18n("S&cript:"), w );
-  l->setAlignment( Qt::AlignTop|Qt::AlignRight );
+  l->setAlignment( TQt::AlignTop|TQt::AlignRight );
   lo->addWidget( l, 2, 1 );
   if ( tool ) teCommand->setText( tool->command );
   TQWhatsThis::add( teCommand, i18n(
@@ -476,7 +476,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
   leExecutable = new TQLineEdit( w );
   lo->addMultiCellWidget( leExecutable, 3, 3, 2, 3 );
   l = new TQLabel( leExecutable, i18n("&Executable:"), w );
-  l->setAlignment( l->alignment()|Qt::AlignRight );
+  l->setAlignment( l->alignment()|TQt::AlignRight );
   lo->addWidget( l, 3, 1 );
   if ( tool ) leExecutable->setText( tool->tryexec );
   TQWhatsThis::add( leExecutable, i18n(
@@ -487,7 +487,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
   leMimetypes = new TQLineEdit( w );
   lo->addWidget( leMimetypes, 4, 2 );
   l = new TQLabel( leMimetypes, i18n("&Mime types:"), w );
-  l->setAlignment( l->alignment()|Qt::AlignRight );
+  l->setAlignment( l->alignment()|TQt::AlignRight );
   lo->addWidget( l, 4, 1 );
   if ( tool ) leMimetypes->setText( tool->mimetypes.join("; ") );
   TQWhatsThis::add( leMimetypes, i18n(
@@ -498,14 +498,14 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
   TQToolButton *btnMTW = new TQToolButton(w);
   lo->addWidget( btnMTW, 4, 3 );
   btnMTW->setIconSet(TQIconSet(SmallIcon("wizard")));
-  connect(btnMTW, TQT_SIGNAL(clicked()), this, TQT_SLOT(showMTDlg()));
+  connect(btnMTW, TQ_SIGNAL(clicked()), this, TQ_SLOT(showMTDlg()));
   TQWhatsThis::add( btnMTW, i18n(
       "Click for a dialog that can help you creating a list of mimetypes.") );
 
   cmbSave = new TQComboBox(w);
   lo->addMultiCellWidget( cmbSave, 5, 5, 2, 3 );
   l = new TQLabel( cmbSave, i18n("&Save:"), w );
-  l->setAlignment( l->alignment()|Qt::AlignRight );
+  l->setAlignment( l->alignment()|TQt::AlignRight );
   lo->addWidget( l, 5, 1 );
   TQStringList sl;
   sl << i18n("None") << i18n("Current Document") << i18n("All Documents");
@@ -520,7 +520,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
   leCmdLine = new TQLineEdit( w );
   lo->addMultiCellWidget( leCmdLine, 6, 6, 2, 3 );
   l = new TQLabel( leCmdLine, i18n("&Command line name:"), w );
-  l->setAlignment( l->alignment()|Qt::AlignRight );
+  l->setAlignment( l->alignment()|TQt::AlignRight );
   lo->addWidget( l, 6, 1 );
   if ( tool ) leCmdLine->setText( tool->cmdname );
   TQWhatsThis::add( leCmdLine, i18n(
@@ -562,33 +562,33 @@ KateExternalToolsConfigWidget::KateExternalToolsConfigWidget( TQWidget *parent,
 
   lbTools = new TDEListBox( this );
   lo->addMultiCellWidget( lbTools, 1, 4, 0, 3 );
-  connect( lbTools, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(slotSelectionChanged()) );
+  connect( lbTools, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(slotSelectionChanged()) );
 
   btnNew = new TQPushButton( i18n("&New..."), this );
   lo->addWidget( btnNew, 5, 0 );
-  connect( btnNew, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotNew()) );
+  connect( btnNew, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotNew()) );
 
   btnRemove = new TQPushButton( i18n("&Remove"), this );
   lo->addWidget( btnRemove, 5, 2 );
-  connect( btnRemove, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotRemove()) );
+  connect( btnRemove, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotRemove()) );
 
   btnEdit = new TQPushButton( i18n("&Edit..."), this );
   lo->addWidget( btnEdit, 5, 1 );
-  connect( btnEdit, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotEdit()) );
+  connect( btnEdit, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEdit()) );
 
   TQPushButton *b = new TQPushButton( i18n("Insert &Separator"), this );
   lo->addWidget( b, 5, 3 );
-  connect( b, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotInsertSeparator()) );
+  connect( b, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotInsertSeparator()) );
 
   btnMoveUp = new TQPushButton( SmallIconSet("go-up"), "", this );
   lo->addWidget( btnMoveUp, 2, 4 );
-  connect( btnMoveUp, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotMoveUp()) );
+  connect( btnMoveUp, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotMoveUp()) );
 
   btnMoveDwn = new TQPushButton( SmallIconSet("go-down"), "", this );
   lo->addWidget( btnMoveDwn, 3, 4 );
-  connect( btnMoveDwn, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotMoveDown()) );
+  connect( btnMoveDwn, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotMoveDown()) );
 
-  connect( lbTools, TQT_SIGNAL( doubleClicked ( TQListBoxItem * ) ), this,  TQT_SLOT( slotEdit() ) );
+  connect( lbTools, TQ_SIGNAL( doubleClicked ( TQListBoxItem * ) ), this,  TQ_SLOT( slotEdit() ) );
 
   lo->setRowStretch( 1, 1 );
   lo->setRowStretch( 4, 1 );
