@@ -71,8 +71,8 @@ ToggleToolViewAction::ToggleToolViewAction ( const TQString& text, const TDEShor
  : TDEToggleAction(text,cut,parent,name)
  , m_tv(tv)
 {
-  connect(this,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotToggled(bool)));
-  connect(m_tv,TQT_SIGNAL(visibleChanged(bool)),this,TQT_SLOT(visibleChanged(bool)));
+  connect(this,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(slotToggled(bool)));
+  connect(m_tv,TQ_SIGNAL(visibleChanged(bool)),this,TQ_SLOT(visibleChanged(bool)));
 
   setChecked(m_tv->visible());
 }
@@ -123,8 +123,8 @@ GUIClient::GUIClient ( MainWindow *mw )
  , KXMLGUIClient ( mw )
  , m_mw (mw)
 {
-  connect( m_mw->guiFactory(), TQT_SIGNAL( clientAdded( KXMLGUIClient * ) ),
-           this, TQT_SLOT( clientAdded( KXMLGUIClient * ) ) );
+  connect( m_mw->guiFactory(), TQ_SIGNAL( clientAdded( KXMLGUIClient * ) ),
+           this, TQ_SLOT( clientAdded( KXMLGUIClient * ) ) );
 
   if ( domDocument().documentElement().isNull() )
   {
@@ -142,8 +142,8 @@ GUIClient::GUIClient ( MainWindow *mw )
                                             CTRL|ALT|SHIFT|Key_F, actionCollection(), "kate_mdi_sidebar_visibility" );
   m_showSidebarsAction->setCheckedState(i18n("Hide Side&bars"));
   m_showSidebarsAction->setChecked( m_mw->sidebarsVisible() );
-  connect( m_showSidebarsAction, TQT_SIGNAL( toggled( bool ) ),
-           m_mw, TQT_SLOT( setSidebarsVisible( bool ) ) );
+  connect( m_showSidebarsAction, TQ_SIGNAL( toggled( bool ) ),
+           m_mw, TQ_SLOT( setSidebarsVisible( bool ) ) );
 
   m_toolMenu->insert( m_showSidebarsAction );
   m_toolMenu->insert( new TDEActionSeparator( m_toolMenu ) );
@@ -256,8 +256,8 @@ bool ToolView::visible () const
 void ToolView::childEvent ( TQChildEvent *ev )
 {
   // set the widget to be focus proxy if possible
-  if (ev->inserted() && ev->child() && TQT_TQOBJECT(ev->child())->tqt_cast("TQWidget")) {
-    setFocusProxy (::tqqt_cast<TQWidget*>(TQT_TQOBJECT(ev->child())));
+  if (ev->inserted() && ev->child() && ev->child()->tqt_cast("TQWidget")) {
+    setFocusProxy (::tqt_cast<TQWidget*>(ev->child()));
 }
 
   TQVBox::childEvent (ev);
@@ -286,7 +286,7 @@ Sidebar::~Sidebar ()
 void Sidebar::setSplitter (Splitter *sp)
 {
   m_splitter = sp;
-  m_ownSplit = new Splitter ((position() == KMultiTabBar::Top || position() == KMultiTabBar::Bottom) ? Qt::Horizontal : Qt::Vertical, m_splitter);
+  m_ownSplit = new Splitter ((position() == KMultiTabBar::Top || position() == KMultiTabBar::Bottom) ? TQt::Horizontal : TQt::Vertical, m_splitter);
   m_ownSplit->setOpaqueResize( TDEGlobalSettings::opaqueResize() );
   m_ownSplit->setChildrenCollapsible( false );
   m_splitter->setResizeMode( m_ownSplit, TQSplitter::KeepSize );
@@ -332,7 +332,7 @@ ToolView *Sidebar::addWidget (const TQPixmap &icon, const TQString &text, ToolVi
 
   show ();
 
-  connect(tab(newId),TQT_SIGNAL(clicked(int)),this,TQT_SLOT(tabClicked(int)));
+  connect(tab(newId),TQ_SIGNAL(clicked(int)),this,TQ_SLOT(tabClicked(int)));
   tab(newId)->installEventFilter(this);
 
   return widget;
@@ -449,7 +449,7 @@ bool Sidebar::eventFilter(TQObject *obj, TQEvent *ev)
   if (ev->type()==TQEvent::ContextMenu)
   {
     TQContextMenuEvent *e = (TQContextMenuEvent *) ev;
-    KMultiTabBarTab *bt = tqt_dynamic_cast<KMultiTabBarTab*>(obj);
+    KMultiTabBarTab *bt = dynamic_cast<KMultiTabBarTab*>(obj);
     if (bt)
     {
       kdDebug()<<"Request for popup"<<endl;
@@ -480,8 +480,8 @@ bool Sidebar::eventFilter(TQObject *obj, TQEvent *ev)
         if (position() != 3)
           p->insertItem(SmallIconSet("go-down"), i18n("Bottom Sidebar"),3);
 
-        connect(p, TQT_SIGNAL(activated(int)),
-              this, TQT_SLOT(buttonPopupActivate(int)));
+        connect(p, TQ_SIGNAL(activated(int)),
+              this, TQ_SLOT(buttonPopupActivate(int)));
 
         p->exec(e->globalPos());
         delete p;
@@ -596,7 +596,7 @@ void Sidebar::restoreSession (TDEConfig *config)
       // readd the button
       int newId = m_widgetToId[tv];
       appendTab (tv->icon, newId, tv->text);
-      connect(tab(newId),TQT_SIGNAL(clicked(int)),this,TQT_SLOT(tabClicked(int)));
+      connect(tab(newId),TQ_SIGNAL(clicked(int)),this,TQ_SLOT(tabClicked(int)));
       tab(newId)->installEventFilter(this);
 
       // reshuffle in splitter
@@ -672,7 +672,7 @@ MainWindow::MainWindow (TQWidget* parentWidget, const char* name)
 
   m_sidebars[KMultiTabBar::Left] = new Sidebar (KMultiTabBar::Left, this, hb);
 
-  m_hSplitter = new Splitter (Qt::Horizontal, hb);
+  m_hSplitter = new Splitter (TQt::Horizontal, hb);
   m_hSplitter->setOpaqueResize( TDEGlobalSettings::opaqueResize() );
 
   m_sidebars[KMultiTabBar::Left]->setSplitter (m_hSplitter);
@@ -682,7 +682,7 @@ MainWindow::MainWindow (TQWidget* parentWidget, const char* name)
 
   m_sidebars[KMultiTabBar::Top] = new Sidebar (KMultiTabBar::Top, this, vb);
 
-  m_vSplitter = new Splitter (Qt::Vertical, vb);
+  m_vSplitter = new Splitter (TQt::Vertical, vb);
   m_vSplitter->setOpaqueResize( TDEGlobalSettings::opaqueResize() );
 
   m_sidebars[KMultiTabBar::Top]->setSplitter (m_vSplitter);
