@@ -536,7 +536,7 @@ static TDECmdLineOptions options[] =
   TDECmdLineLastOption
 };
 
-extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
+extern "C" TDE_EXPORT int kdemain(int argc, char **argv)
 {
   Kate::Document::setFileChangedDialogsActivated (true);
 
