@@ -59,11 +59,11 @@ KfindTabWidget::KfindTabWidget(TQWidget *parent, const char *name)
 
     pages[0] = new TQWidget( this, "page1" );
 
-    nameBox = new KComboBox(TRUE, pages[0], "combo1");
+    nameBox = new KComboBox(true, pages[0], "combo1");
     nameBox->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);  // allow smaller than widest entry
     TQLabel * namedL = new TQLabel(nameBox, i18n("&Named:"), pages[0], "named");
     TQToolTip::add( namedL, i18n("You can use wildcard matching and \";\" for separating multiple names") );
-    dirBox  = new KComboBox(TRUE, pages[0], "combo2");
+    dirBox  = new KComboBox(true, pages[0], "combo2");
     dirBox->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);  // allow smaller than widest entry
     TQLabel * lookinL = new TQLabel(dirBox, i18n("Look &in:"), pages[0], "named");
     subdirsCb  = new TQCheckBox(i18n("Include &subfolders"), pages[0]);
@@ -79,9 +79,9 @@ KfindTabWidget::KfindTabWidget(TQWidget *parent, const char *name)
     if(TDEStandardDirs::findExe("locate")==NULL)
     	useLocateCb->setEnabled(false);
 
-    nameBox->setDuplicatesEnabled(FALSE);
+    nameBox->setDuplicatesEnabled(false);
     nameBox->setFocus();
-    dirBox->setDuplicatesEnabled(FALSE);
+    dirBox->setDuplicatesEnabled(false);
 
     nameBox->setInsertionPolicy(TQComboBox::AtTop);
     dirBox->setInsertionPolicy(TQComboBox::AtTop);
@@ -134,11 +134,11 @@ KfindTabWidget::KfindTabWidget(TQWidget *parent, const char *name)
 
     // Signals
 
-    connect( browseB, TQT_SIGNAL(clicked()),
-             this, TQT_SLOT(getDirectory()) );
+    connect( browseB, TQ_SIGNAL(clicked()),
+             this, TQ_SLOT(getDirectory()) );
 
-    connect( nameBox, TQT_SIGNAL(activated(int)),
-             this, TQT_SIGNAL(startSearch()));
+    connect( nameBox, TQ_SIGNAL(activated(int)),
+             this, TQ_SIGNAL(startSearch()));
 
     // ************ Page Two
 
@@ -149,7 +149,7 @@ KfindTabWidget::KfindTabWidget(TQWidget *parent, const char *name)
     rb[0] = new TQRadioButton(i18n("&between"), pages[1] );
     rb[1] = new TQRadioButton(i18n("&during the previous"), pages[1] );
     TQLabel * andL   = new TQLabel(i18n("and"), pages[1], "and");
-    betweenType = new KComboBox(FALSE, pages[1], "comboBetweenType");
+    betweenType = new KComboBox(false, pages[1], "comboBetweenType");
     betweenType->insertItem(i18n("minute(s)"));
     betweenType->insertItem(i18n("hour(s)"));
     betweenType->insertItem(i18n("day(s)"));
@@ -164,11 +164,11 @@ KfindTabWidget::KfindTabWidget(TQWidget *parent, const char *name)
     toDate = new KDateCombo(pages[1], "toDate");
     timeBox = new TQSpinBox(1, 60, 1, pages[1], "timeBox");
 
-    sizeBox =new KComboBox(FALSE, pages[1], "sizeBox");
+    sizeBox =new KComboBox(false, pages[1], "sizeBox");
     TQLabel * sizeL   =new TQLabel(sizeBox,i18n("File &size is:"), pages[1],"size");
     sizeEdit=new TQSpinBox(0, INT_MAX, 1, pages[1], "sizeEdit" );
     sizeEdit->setValue(1);
-    sizeUnitBox =new KComboBox(FALSE, pages[1], "sizeUnitBox");
+    sizeUnitBox =new KComboBox(false, pages[1], "sizeUnitBox");
 
     m_usernameBox = new KComboBox( true, pages[1], "m_combo1");
     TQLabel *usernameLabel= new TQLabel(m_usernameBox,i18n("Files owned by &user:"),pages[1]);
@@ -189,8 +189,8 @@ KfindTabWidget::KfindTabWidget(TQWidget *parent, const char *name)
     int tmp = sizeEdit->fontMetrics().width(" 000000000 ");
     sizeEdit->setMinimumSize(tmp, sizeEdit->sizeHint().height());
 
-    m_usernameBox->setDuplicatesEnabled(FALSE);
-    m_groupBox->setDuplicatesEnabled(FALSE);
+    m_usernameBox->setDuplicatesEnabled(false);
+    m_groupBox->setDuplicatesEnabled(false);
     m_usernameBox->setInsertionPolicy(TQComboBox::AtTop);
     m_groupBox->setInsertionPolicy(TQComboBox::AtTop);
 
@@ -212,7 +212,7 @@ KfindTabWidget::KfindTabWidget(TQWidget *parent, const char *name)
 
     grid1->addWidget(rb[0], 1, 1 );
     grid1->addWidget(fromDate, 1, 2 );
-    grid1->addWidget(andL, 1, 3, Qt::AlignHCenter );
+    grid1->addWidget(andL, 1, 3, TQt::AlignHCenter );
     grid1->addWidget(toDate, 1, 4 );
 
     grid1->addWidget(rb[1], 2, 1 );
@@ -235,22 +235,22 @@ KfindTabWidget::KfindTabWidget(TQWidget *parent, const char *name)
     grid1->setRowStretch(6,1);
 
     // Connect
-    connect( findCreated,  TQT_SIGNAL(toggled(bool)),   TQT_SLOT(fixLayout()) );
-    connect( bg,  TQT_SIGNAL(clicked(int)), this,   TQT_SLOT(fixLayout()) );
-    connect( sizeBox, TQT_SIGNAL(highlighted(int)), this, TQT_SLOT(slotSizeBoxChanged(int)));
+    connect( findCreated,  TQ_SIGNAL(toggled(bool)),   TQ_SLOT(fixLayout()) );
+    connect( bg,  TQ_SIGNAL(clicked(int)), this,   TQ_SLOT(fixLayout()) );
+    connect( sizeBox, TQ_SIGNAL(highlighted(int)), this, TQ_SLOT(slotSizeBoxChanged(int)));
 
 
     // ************ Page Three
 
     pages[2] = new TQWidget( this, "page3" );
 
-    typeBox =new KComboBox(FALSE, pages[2], "typeBox");
+    typeBox =new KComboBox(false, pages[2], "typeBox");
     typeBox->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);  // allow smaller than widest entry
     TQLabel * typeL   =new TQLabel(typeBox, i18n("File &type:"), pages[2], "type");
     textEdit=new KLineEdit(pages[2], "textEdit" );
     TQLabel * textL   =new TQLabel(textEdit, i18n("C&ontaining text:"), pages[2], "text");
 
-    connect( textEdit, TQT_SIGNAL(returnPressed(const TQString &)), TQT_SIGNAL( startSearch()));
+    connect( textEdit, TQ_SIGNAL(returnPressed(const TQString &)), TQ_SIGNAL( startSearch()));
 
     const TQString containingtext
       = i18n("<qt>If specified, only files that contain this text"
@@ -306,9 +306,9 @@ KfindTabWidget::KfindTabWidget(TQWidget *parent, const char *name)
 
     if ( editRegExp ) {
       // The editor was available, so lets use it.
-      connect( regexpContentCb, TQT_SIGNAL(toggled(bool) ), editRegExp, TQT_SLOT(setEnabled(bool)) );
+      connect( regexpContentCb, TQ_SIGNAL(toggled(bool) ), editRegExp, TQ_SLOT(setEnabled(bool)) );
       editRegExp->setEnabled(false);
-      connect( editRegExp, TQT_SIGNAL(clicked()), this, TQT_SLOT( slotEditRegExp() ) );
+      connect( editRegExp, TQ_SIGNAL(clicked()), this, TQ_SLOT( slotEditRegExp() ) );
     }
     else
         regexpContentCb->hide();
@@ -330,7 +330,7 @@ KfindTabWidget::KfindTabWidget(TQWidget *parent, const char *name)
 
     grid2->addWidget( textMetaKey, 4, 0 );
     grid2->addWidget( metainfokeyEdit, 4, 1 );
-    grid2->addWidget( textMetaInfo, 4, 2, Qt::AlignHCenter  );
+    grid2->addWidget( textMetaInfo, 4, 2, TQt::AlignHCenter  );
     grid2->addWidget( metainfoEdit, 4, 3 );
 
     metainfokeyEdit->setText("*");
@@ -496,7 +496,7 @@ void KfindTabWidget::loadHistory()
 void KfindTabWidget::slotEditRegExp()
 {
   if ( ! regExpDialog )
-    regExpDialog = KParts::ComponentFactory::createInstanceFromQuery<TQDialog>( "KRegExpEditor/KRegExpEditor", TQString(), TQT_TQOBJECT(this) );
+    regExpDialog = KParts::ComponentFactory::createInstanceFromQuery<TQDialog>( "KRegExpEditor/KRegExpEditor", TQString(), this );
 
   KRegExpEditorInterface *iface = static_cast<KRegExpEditorInterface *>( regExpDialog->tqt_cast( "KRegExpEditorInterface" ) );
   if ( !iface )
@@ -543,18 +543,18 @@ void KfindTabWidget::setDefaults()
 bool KfindTabWidget::isDateValid()
 {
   // All files
-  if ( !findCreated->isChecked() ) return TRUE;
+  if ( !findCreated->isChecked() ) return true;
 
   if (rb[1]->isChecked())
   {
-    if (timeBox->value() > 0 ) return TRUE;
+    if (timeBox->value() > 0 ) return true;
 
     KMessageBox::sorry(this, i18n("Unable to search within a period that is less than a minute."));
-    return FALSE;
+    return false;
   }
 
   // If we can not parse either of the dates or
-  // "from" date is bigger than "to" date return FALSE.
+  // "from" date is bigger than "to" date return false.
   TQDate hi1, hi2;
 
   TQString str;
@@ -568,9 +568,9 @@ bool KfindTabWidget::isDateValid()
 
   if (!str.isNull()) {
     KMessageBox::sorry(0, str);
-    return FALSE;
+    return false;
   }
-  return TRUE;
+  return true;
 }
 
 void KfindTabWidget::setQuery(KQuery *query)
@@ -756,12 +756,12 @@ void KfindTabWidget::beginSearch()
 ///  dirlister->openURL(KURL(dirBox->currentText().stripWhiteSpace()));
 
   saveHistory();
-  setEnabled( FALSE );
+  setEnabled( false );
 }
 
 void KfindTabWidget::endSearch()
 {
-  setEnabled( TRUE );
+  setEnabled( true );
 }
 
 /*
@@ -775,16 +775,16 @@ void KfindTabWidget::fixLayout()
   // and second radio group on page two
 
   if(! findCreated->isChecked())  {
-    fromDate->setEnabled(FALSE);
-    toDate->setEnabled(FALSE);
-    timeBox->setEnabled(FALSE);
+    fromDate->setEnabled(false);
+    toDate->setEnabled(false);
+    timeBox->setEnabled(false);
     for(i=0; i<2; i++)
-      rb[i]->setEnabled(FALSE);
-    betweenType->setEnabled(FALSE);
+      rb[i]->setEnabled(false);
+    betweenType->setEnabled(false);
   }
   else {
     for(i=0; i<2; i++)
-      rb[i]->setEnabled(TRUE);
+      rb[i]->setEnabled(true);
 
     fromDate->setEnabled(rb[0]->isChecked());
     toDate->setEnabled(rb[0]->isChecked());
@@ -807,7 +807,7 @@ bool KfindTabWidget::isSearchRecursive()
    Digit validator. Allows only digits to be typed.
 **/
 KDigitValidator::KDigitValidator( TQWidget * parent, const char *name )
-  : TQValidator( TQT_TQOBJECT(parent), name )
+  : TQValidator( parent, name )
 {
   r = new TQRegExp("^[0-9]*$");
 }
