@@ -70,7 +70,7 @@ namespace TaskMoveDestination
 
 class TaskBar : public Panner
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     TaskBar( TaskBarSettings* settingsObject, TaskBarSettings* globalSettingsObject, TQWidget *parent = 0, const char *name = 0 );
