@@ -87,7 +87,7 @@ class KonqExtendedBookmarkOwner;
 
 class KonqMainWindow : public KParts::MainWindow, public KonqFrameContainerBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   TQ_PROPERTY( int viewCount READ viewCount )
   TQ_PROPERTY( int activeViewsCount READ activeViewsCount )
   TQ_PROPERTY( int linkableViewsCount READ linkableViewsCount )
@@ -282,7 +282,7 @@ public:
   void printFrameInfo( const TQString &spaces );
 
   void reparentFrame( TQWidget* parent,
-                              const TQPoint & p, bool showIt=FALSE );
+                              const TQPoint & p, bool showIt=false );
 
   KonqFrameContainerBase* parentContainer()const;
   void setParentContainer(KonqFrameContainerBase* parent);
