@@ -11,6 +11,7 @@ Copyright (C) 2000 Matthias Ettrich <ettrich@kde.org>
 #endif
 
 #include "shutdowndlg.h"
+#include "server.h"
 
 #include <tqapplication.h>
 #include <tqlayout.h>
@@ -77,12 +78,12 @@ KSMShutdownFeedback::KSMShutdownFeedback()
    m_currentY( 0 ),
    m_grayOpacity( 0.0f ),
    m_compensation( 0.0f ),
-   m_fadeBackwards( FALSE ),
+   m_fadeBackwards( false ),
    m_unfadedImage(),
    m_grayImage(),
    m_fadeTime(),
    m_pmio(),
-   m_greyImageCreated( FALSE )
+   m_greyImageCreated( false )
 
 {
 	if (kapp->isX11CompositionAvailable()) {
@@ -105,14 +106,14 @@ KSMShutdownFeedback::KSMShutdownFeedback()
 	m_unfadedImage = m_grayImage;
 	resize(0, 0);
 	setShown(true);
-	TQTimer::singleShot( 500, this, TQT_SLOT( slotPaintEffect() ) );
+	TQTimer::singleShot( 500, this, TQ_SLOT( slotPaintEffect() ) );
 }
 
 // called after stopping shutdown-feedback -> smooth fade-back to color-mode
 void KSMShutdownFeedback::fadeBack( void )
 {
 	m_fadeTime.restart();
-	m_fadeBackwards = TRUE;
+	m_fadeBackwards = true;
 	// its possible that we have to fade back, before all is completely gray, so we cannot start
 	// with completely gray when fading back...
 	m_compensation = 1.0f - m_grayOpacity;
@@ -136,7 +137,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 			// if slotPaintEffect() is called first time, we have to initialize the gray image
 			// we also could do that in the constructor, but then the displaying of the
 			// logout-UI would be too much delayed...
-			if ( m_greyImageCreated == false )
+			if ( !m_greyImageCreated )
 			{
 				m_greyImageCreated = true;
 
@@ -169,11 +170,11 @@ void KSMShutdownFeedback::slotPaintEffect()
 			}
 
 			// return if fading is completely done...
-			if ( ( m_grayOpacity >= 1.0f && m_fadeBackwards == FALSE ) || ( m_grayOpacity <= 0.0f && m_fadeBackwards == TRUE ) )
+			if ( ( m_grayOpacity >= 1.0f && !m_fadeBackwards ) || ( m_grayOpacity <= 0.0f && m_fadeBackwards ) )
 				return;
 
 
-			if ( m_fadeBackwards == FALSE )
+			if ( !m_fadeBackwards )
 			{
 				m_grayOpacity = m_fadeTime.elapsed() / doFancyLogoutFadeTime;
 				if ( m_grayOpacity > 1.0f )
@@ -200,7 +201,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 			if( y2 > imgHeight )
 				y2 = imgHeight;
 
-			if( m_fadeBackwards == FALSE )
+			if( !m_fadeBackwards )
 			{
 				if( y1 > 0 && y1 < imgHeight && y1-m_rowsDone > 0 && m_rowsDone < imgHeight )
 				{
@@ -243,13 +244,13 @@ void KSMShutdownFeedback::slotPaintEffect()
 				bitBlt( this, 0, start_y1, &img );
 			}
 
-			TQTimer::singleShot( 5, this, TQT_SLOT( slotPaintEffect() ) );
+			TQTimer::singleShot( 5, this, TQ_SLOT( slotPaintEffect() ) );
 		}
 		else {
 			// if slotPaintEffect() is called first time, we have to initialize the gray image
 			// we also could do that in the constructor, but then the displaying of the
 			// logout-UI would be too much delayed...
-			if ( m_greyImageCreated == false )
+			if ( !m_greyImageCreated )
 			{
 				m_greyImageCreated = true;
 
@@ -277,11 +278,11 @@ void KSMShutdownFeedback::slotPaintEffect()
 			}
 
 			// return if fading is completely done...
-			if ( ( m_grayOpacity >= 1.0f && m_fadeBackwards == FALSE ) || ( m_grayOpacity <= 0.0f && m_fadeBackwards == TRUE ) )
+			if ( ( m_grayOpacity >= 1.0f && !m_fadeBackwards ) || ( m_grayOpacity <= 0.0f && m_fadeBackwards ) )
 				return;
 
 
-			if ( m_fadeBackwards == FALSE )
+			if ( !m_fadeBackwards )
 			{
 				m_grayOpacity = m_fadeTime.elapsed() / doFancyLogoutFadeTime;
 				if ( m_grayOpacity > 1.0f )
@@ -308,7 +309,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 			if( y2 > imgHeight )
 				y2 = imgHeight;
 
-			if( m_fadeBackwards == FALSE )
+			if( !m_fadeBackwards )
 			{
 				if( y1 > 0 && y1 < imgHeight && y1-m_rowsDone > 0 && m_rowsDone < imgHeight )
 				{
@@ -370,7 +371,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 				bitBlt( this, 0, start_y1, &img );
 			}
 
-			TQTimer::singleShot( 5, this, TQT_SLOT( slotPaintEffect() ) );
+			TQTimer::singleShot( 5, this, TQ_SLOT( slotPaintEffect() ) );
 		}
 	}
 	else {
@@ -381,7 +382,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 				// The end effect will be very similar to the old style logout
 				float doFancyLogoutFadeTime = 1000;
 				float doFancyLogoutFadeBackTime = 0;
-				if ( m_greyImageCreated == false ) {
+				if ( !m_greyImageCreated ) {
 					m_greyImageCreated = true;
 
 					// eliminate nasty flicker on first show
@@ -413,11 +414,11 @@ void KSMShutdownFeedback::slotPaintEffect()
 				}
 
 				// return if fading is completely done...
-				if ( ( m_grayOpacity >= 1.0f && m_fadeBackwards == FALSE ) || ( m_grayOpacity <= 0.0f && m_fadeBackwards == TRUE ) ) {
+				if ( ( m_grayOpacity >= 1.0f && !m_fadeBackwards ) || ( m_grayOpacity <= 0.0f && m_fadeBackwards ) ) {
 					return;
 				}
 
-				if ( m_fadeBackwards == FALSE ) {
+				if ( !m_fadeBackwards ) {
 					m_grayOpacity = m_fadeTime.elapsed() / doFancyLogoutFadeTime;
 					if ( m_grayOpacity > 1.0f )
 					m_grayOpacity = 1.0f;
@@ -444,7 +445,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 					y2 = imgHeight;
 				}
 
-				if( m_fadeBackwards == FALSE )
+				if( !m_fadeBackwards )
 				{
 					if( y1 > 0 && y1 < imgHeight && y1-m_rowsDone > 0 && m_rowsDone < imgHeight )
 					{
@@ -486,7 +487,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 					bitBlt( this, 0, start_y1, &img );
 				}
 
-				TQTimer::singleShot( 1, this, TQT_SLOT( slotPaintEffect() ) );
+				TQTimer::singleShot( 1, this, TQ_SLOT( slotPaintEffect() ) );
 			 }
 			 else {
 				if ( m_currentY >= height() ) {
@@ -511,13 +512,13 @@ void KSMShutdownFeedback::slotPaintEffect()
 				KPixmap pixmap;
 				pixmap = TQPixmap(TQPixmap::grabWindow( tqt_xrootwin(), 0, m_currentY, width(), 10 ));
 				TQImage image = pixmap.convertToImage();
-				KImageEffect::blend( Qt::black, image, 0.4 );
+				KImageEffect::blend( TQt::black, image, 0.4 );
 				KImageEffect::toGray( image, true );
 				pixmap.convertFromImage( image );
 				bitBlt( this, 0, m_currentY, &pixmap );
 				bitBlt( &m_root, 0, m_currentY, &pixmap );
 				m_currentY += 10;
-				TQTimer::singleShot( 1, this, TQT_SLOT( slotPaintEffect() ) );
+				TQTimer::singleShot( 1, this, TQ_SLOT( slotPaintEffect() ) );
 			}
 		}
 	}
@@ -529,7 +530,7 @@ void KSMShutdownFeedback::slotPaintEffect()
 KSMShutdownIPFeedback * KSMShutdownIPFeedback::s_pSelf = 0L;
 
 KSMShutdownIPFeedback::KSMShutdownIPFeedback()
-: TQWidget( 0L, "systemmodaldialogclass", Qt::WStyle_Customize | Qt::WStyle_NoBorder | Qt::WStyle_StaysOnTop ), m_timeout(0), m_isPainted(false), m_paintedFromSharedRootPixmap(false), m_sharedRootPixmap(NULL), mPixmapTimeout(0)
+: TQWidget( 0L, "systemmodaldialogclass", TQt::WStyle_Customize | TQt::WStyle_NoBorder | TQt::WStyle_StaysOnTop ), m_timeout(0), m_isPainted(false), m_paintedFromSharedRootPixmap(false), m_sharedRootPixmap(NULL), mPixmapTimeout(0)
 
 {
 	setShown(false);
@@ -539,7 +540,7 @@ KSMShutdownIPFeedback::KSMShutdownIPFeedback()
 
 	m_sharedRootPixmap = new KRootPixmap(this);
 	m_sharedRootPixmap->setCustomPainting(true);
-	connect(m_sharedRootPixmap, TQT_SIGNAL(backgroundUpdated(const TQPixmap &)), this, TQT_SLOT(slotSetBackgroundPixmap(const TQPixmap &)));
+	connect(m_sharedRootPixmap, TQ_SIGNAL(backgroundUpdated(const TQPixmap &)), this, TQ_SLOT(slotSetBackgroundPixmap(const TQPixmap &)));
 
 	if (TQPaintDevice::x11AppDepth() == 32) {
 		// The shared pixmap is 24 bits, but we are 32 bits
@@ -571,13 +572,13 @@ void KSMShutdownIPFeedback::showNow()
 
 	if (!m_isPainted) {
 		setGeometry( TQApplication::desktop()->geometry() );
-		TQTimer::singleShot( 0, this, SLOT(slotPaintEffect()) );
+		TQTimer::singleShot( 0, this, TQ_SLOT(slotPaintEffect()) );
 	}
 }
 
 void KSMShutdownIPFeedback::enableExports()
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 	kdDebug(270) << k_lineinfo << "activating background exports.\n";
 	DCOPClient *client = kapp->dcopClient();
 	if (!client->isAttached()) {
@@ -632,7 +633,7 @@ void KSMShutdownIPFeedback::slotPaintEffect()
 			m_sharedRootPixmap->start();
 		}
 
-		TQTimer::singleShot( 100, this, SLOT(slotPaintEffect()) );
+		TQTimer::singleShot( 100, this, TQ_SLOT(slotPaintEffect()) );
 		mPixmapTimeout++;
 		return;
 	}
@@ -647,13 +648,13 @@ void KSMShutdownIPFeedback::slotPaintEffect()
 	}
 	if ((pm.isNull()) || (pm.width() != kapp->desktop()->width()) || (pm.height() != kapp->desktop()->height())) {
 		if (mPixmapTimeout < 10) {
-			TQTimer::singleShot( 100, this, SLOT(slotPaintEffect()) );
+			TQTimer::singleShot( 100, this, TQ_SLOT(slotPaintEffect()) );
 			mPixmapTimeout++;
 			return;
 		}
 		else {
 			pm = TQPixmap(kapp->desktop()->width(), kapp->desktop()->height());
-			pm.fill(Qt::black);
+			pm.fill(TQt::black);
 			m_paintedFromSharedRootPixmap = false;
 		}
 	}
@@ -703,7 +704,7 @@ void KSMShutdownIPFeedback::slotPaintEffect()
 
 KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 								bool maysd, bool mayrb, TDEApplication::ShutdownType sdtype, int* selection )
-  : TQDialog( parent, 0, TRUE, (WFlags)WType_Popup ), targets(0), m_selection(selection)
+  : TQDialog( parent, 0, true, (WFlags)WType_Popup ), targets(0), m_selection(selection)
 	// this is a WType_Popup on purpose. Do not change that! Not
 	// having a popup here has severe side effects.
 
@@ -757,7 +758,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 	{
 		// first line of buttons
 		hbuttonbox = new TQHBoxLayout( hbox, factor * KDialog::spacingHint() );
-		hbuttonbox->setAlignment( Qt::AlignHCenter );
+		hbuttonbox->setAlignment( TQt::AlignHCenter );
 		// End session
 		FlatButton* btnLogout = new FlatButton( frame );
 		btnLogout->setTextLabel( TQString("&") + i18n("Log out"), false );
@@ -766,7 +767,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 		int i = btnLogout->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 		btnLogout->setAccel( "ALT+" + btnLogout->textLabel().lower()[i+1] ) ;
 		hbuttonbox->addWidget ( btnLogout );
-		connect(btnLogout, TQT_SIGNAL(clicked()), TQT_SLOT(slotLogout()));
+		connect(btnLogout, TQ_SIGNAL(clicked()), TQ_SLOT(slotLogout()));
 	}
 	else
 	{
@@ -776,7 +777,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 		hbox->addWidget( lfrm, AlignCenter );
 
 		buttonlay = new TQVBoxLayout( hbox, factor * KDialog::spacingHint() );
-		buttonlay->setAlignment( Qt::AlignHCenter );
+		buttonlay->setAlignment( TQt::AlignHCenter );
 
 		TQLabel* icon = new TQLabel( lfrm );
 		if (TDEConfigGroup(TDEGlobal::config(), "Logout").readBoolEntry("doNotUseKonqyPicture", false)) {
@@ -794,7 +795,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 		TQToolTip::add( btnLogout, i18n( "<qt><p>Log out of the current session to login as a different user.</p></qt>" ) );
 		btnFont = btnLogout->font();
 		buttonlay->addWidget( btnLogout );
-		connect(btnLogout, TQT_SIGNAL(clicked()), TQT_SLOT(slotLogout()));
+		connect(btnLogout, TQ_SIGNAL(clicked()), TQ_SLOT(slotLogout()));
 	}
 
 	if ((maysd) || (mayrb)) {
@@ -804,7 +805,6 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 		TDEConfig config("power-managerrc");
 		bool disableSuspend = config.readBoolEntry("disableSuspend", false);
 		bool disableHibernate = config.readBoolEntry("disableHibernate", false);
-		m_lockOnResume = config.readBoolEntry("lockOnResume", true);
 
 		bool canFreeze = false;
 		bool canSuspend = false;
@@ -841,7 +841,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				int i = btnFreeze->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnFreeze->setAccel( "ALT+" + btnFreeze->textLabel().lower()[i+1] ) ;
 				hbuttonbox->addWidget ( btnFreeze );
-				connect(btnFreeze, TQT_SIGNAL(clicked()), TQT_SLOT(slotFreeze()));
+				connect(btnFreeze, TQ_SIGNAL(clicked()), TQ_SLOT(slotFreeze()));
 			}
 
 			if (canSuspend && !disableSuspend)
@@ -857,7 +857,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				int i = btnSuspend->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnSuspend->setAccel( "ALT+" + btnSuspend->textLabel().lower()[i+1] ) ;
 				hbuttonbox->addWidget ( btnSuspend );
-				connect(btnSuspend, TQT_SIGNAL(clicked()), TQT_SLOT(slotSuspend()));
+				connect(btnSuspend, TQ_SIGNAL(clicked()), TQ_SLOT(slotSuspend()));
 			}
 
 			if (canHibernate && !disableHibernate)
@@ -872,7 +872,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				int i = btnHibernate->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnHibernate->setAccel( "ALT+" + btnHibernate->textLabel().lower()[i+1] ) ;
 				hbuttonbox->addWidget ( btnHibernate );
-				connect(btnHibernate, TQT_SIGNAL(clicked()), TQT_SLOT(slotHibernate()));
+				connect(btnHibernate, TQ_SIGNAL(clicked()), TQ_SLOT(slotHibernate()));
 			}
 
 			if (canHybridSuspend && !disableSuspend && !disableHibernate)
@@ -890,15 +890,15 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				int i = btnHybridSuspend->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnHybridSuspend->setAccel( "ALT+" + btnHybridSuspend->textLabel().lower()[i+1] ) ;
 				hbuttonbox->addWidget ( btnHybridSuspend );
-				connect(btnHybridSuspend, TQT_SIGNAL(clicked()), TQT_SLOT(slotHybridSuspend()));
+				connect(btnHybridSuspend, TQ_SIGNAL(clicked()), TQ_SLOT(slotHybridSuspend()));
 			}
-			
+
 			// Separator (within buttonlay)
 			vbox->addWidget( new KSeparator( frame ) );
 
 			// bottom buttons
 			TQHBoxLayout* hbuttonbox2 = new TQHBoxLayout( vbox, factor * KDialog::spacingHint() );
-			hbuttonbox2->setAlignment( Qt::AlignHCenter );
+			hbuttonbox2->setAlignment( TQt::AlignHCenter );
 
 			if (mayrb) {
 				// Reboot
@@ -909,7 +909,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				int i = btnReboot->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnReboot->setAccel( "ALT+" + btnReboot->textLabel().lower()[i+1] ) ;
 				hbuttonbox2->addWidget ( btnReboot);
-				connect(btnReboot, TQT_SIGNAL(clicked()), TQT_SLOT(slotReboot()));
+				connect(btnReboot, TQ_SIGNAL(clicked()), TQ_SLOT(slotReboot()));
 				if ( sdtype == TDEApplication::ShutdownTypeReboot ) {
 					btnReboot->setFocus();
 				}
@@ -936,7 +936,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 					}
 
 					btnReboot->setPopup(targets);
-					connect( targets, TQT_SIGNAL(activated(int)), TQT_SLOT(slotReboot(int)) );
+					connect( targets, TQ_SIGNAL(activated(int)), TQ_SLOT(slotReboot(int)) );
 				}
 				// BAD KARMA .. this code is copied line by line from standard konqy dialog [EOF]
 			}
@@ -950,7 +950,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				int i = btnHalt->textLabel().find( TQRegExp("\\&"), 0 );    // i == 1
 				btnHalt->setAccel( "ALT+" + btnHalt->textLabel().lower()[i+1] ) ;
 				hbuttonbox2->addWidget ( btnHalt );
-				connect(btnHalt, TQT_SIGNAL(clicked()), TQT_SLOT(slotHalt()));
+				connect(btnHalt, TQ_SIGNAL(clicked()), TQ_SLOT(slotHalt()));
 				if ( sdtype == TDEApplication::ShutdownTypeHalt ) {
 					btnHalt->setFocus();
 				}
@@ -958,12 +958,12 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 
 			// cancel buttonbox
 			TQHBoxLayout* hbuttonbox3 = new TQHBoxLayout( vbox, factor * KDialog::spacingHint() );
-			hbuttonbox3->setAlignment( Qt::AlignRight );
+			hbuttonbox3->setAlignment( TQt::AlignRight );
 
 			// Back to Desktop
 			KSMPushButton* btnBack = new KSMPushButton( KStdGuiItem::cancel(), frame );
 			hbuttonbox3->addWidget( btnBack );
-			connect(btnBack, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
+			connect(btnBack, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 
 		}
 		else
@@ -975,7 +975,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				TQToolTip::add( btnHalt, i18n( "<qt><p>Log out of the current session and turn off the computer.</p></qt>" ) );
 				btnHalt->setFont( btnFont );
 				buttonlay->addWidget( btnHalt );
-				connect(btnHalt, TQT_SIGNAL(clicked()), TQT_SLOT(slotHalt()));
+				connect(btnHalt, TQ_SIGNAL(clicked()), TQ_SLOT(slotHalt()));
 				if ( sdtype == TDEApplication::ShutdownTypeHalt || getenv("TDM_AUTOLOGIN") ) {
 					btnHalt->setFocus();
 				}
@@ -988,7 +988,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				btnReboot->setFont( btnFont );
 				buttonlay->addWidget( btnReboot );
 
-				connect(btnReboot, TQT_SIGNAL(clicked()), TQT_SLOT(slotReboot()));
+				connect(btnReboot, TQ_SIGNAL(clicked()), TQ_SLOT(slotReboot()));
 				if ( sdtype == TDEApplication::ShutdownTypeReboot ) {
 					btnReboot->setFocus();
 				}
@@ -1014,7 +1014,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 					}
 
 					btnReboot->setPopup(targets);
-					connect( targets, TQT_SIGNAL(activated(int)), TQT_SLOT(slotReboot(int)) );
+					connect( targets, TQ_SIGNAL(activated(int)), TQ_SLOT(slotReboot(int)) );
 				}
 			}
 
@@ -1026,7 +1026,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				" almost instantly.</p><p>This correspond to ACPI S0 mode.</p></qt>"));
 				btnFreeze->setFont( btnFont );
 				buttonlay->addWidget( btnFreeze );
-				connect(btnFreeze, TQT_SIGNAL(clicked()), TQT_SLOT(slotFreeze()));
+				connect(btnFreeze, TQ_SIGNAL(clicked()), TQ_SLOT(slotFreeze()));
 			}
 
 			if (canSuspend && !disableSuspend)
@@ -1038,7 +1038,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				"<p>Also known as Suspend-to-RAM mode.</p></qt>"));
 				btnSuspend->setFont( btnFont );
 				buttonlay->addWidget( btnSuspend );
-				connect(btnSuspend, TQT_SIGNAL(clicked()), TQT_SLOT(slotSuspend()));
+				connect(btnSuspend, TQ_SIGNAL(clicked()), TQ_SLOT(slotSuspend()));
 			}
 
 			if (canHibernate && !disableHibernate)
@@ -1049,7 +1049,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				" considerable time is required to reactivate the system again.</p><p>This correspond to ACPI S4 mode.</p><p>Also known as Suspend-to-Disk mode.</p></qt>"));
 				btnHibernate->setFont( btnFont );
 				buttonlay->addWidget( btnHibernate );
-				connect(btnHibernate, TQT_SIGNAL(clicked()), TQT_SLOT(slotHibernate()));
+				connect(btnHibernate, TQ_SIGNAL(clicked()), TQ_SLOT(slotHibernate()));
 			}
 
 			if (canHybridSuspend && !disableSuspend && !disableHibernate)
@@ -1063,9 +1063,9 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 				"<p>Also known as Suspend-to-RAM + Suspend-to-Disk mode.</p></qt>"));
 				btnHybridSuspend->setFont( btnFont );
 				buttonlay->addWidget( btnHybridSuspend );
-				connect(btnHybridSuspend, TQT_SIGNAL(clicked()), TQT_SLOT(slotHybridSuspend()));
+				connect(btnHybridSuspend, TQ_SIGNAL(clicked()), TQ_SLOT(slotHybridSuspend()));
 			}
-			
+
 			buttonlay->addStretch( 1 );
 
 			// Separator
@@ -1074,7 +1074,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 			// Back to Desktop
 			KPushButton* btnBack = new KPushButton( KStdGuiItem::cancel(), frame );
 			buttonlay->addWidget( btnBack );
-			connect(btnBack, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
+			connect(btnBack, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 		}
 	}
 	else {
@@ -1083,13 +1083,13 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 		{
 			// cancel buttonbox
 			TQHBoxLayout* hbuttonbox3 = new TQHBoxLayout( vbox, factor * KDialog::spacingHint() );
-			hbuttonbox3->setAlignment( Qt::AlignRight );
+			hbuttonbox3->setAlignment( TQt::AlignRight );
 
 			// Back to Desktop
 			KSMPushButton* btnBack = new KSMPushButton( KStdGuiItem::cancel(), frame );
 			hbuttonbox3->addWidget( btnBack );
 
-			connect(btnBack, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
+			connect(btnBack, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 		}
 		else
 		{
@@ -1100,7 +1100,7 @@ KSMShutdownDlg::KSMShutdownDlg( TQWidget* parent,
 			KPushButton* btnBack = new KPushButton( KStdGuiItem::cancel(), frame );
 			buttonlay->addWidget( btnBack );
 
-			connect(btnBack, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
+			connect(btnBack, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 		}
 	}
 }
@@ -1246,8 +1246,8 @@ KSMShutdownIPDlg::KSMShutdownIPDlg(TQWidget* parent)
 
 	setNotificationActionButtonsSkipText(i18n("Skip Notification"));
 	m_button2->setText(i18n("Abort Logout"));
-	connect(m_button1, SIGNAL(clicked()), this, SIGNAL(skipNotificationClicked()));
-	connect(m_button2, SIGNAL(clicked()), this, SIGNAL(abortLogoutClicked()));
+	connect(m_button1, TQ_SIGNAL(clicked()), this, TQ_SIGNAL(skipNotificationClicked()));
+	connect(m_button2, TQ_SIGNAL(clicked()), this, TQ_SIGNAL(abortLogoutClicked()));
 
 	show();
 	setActiveWindow();
@@ -1264,10 +1264,10 @@ KSMDelayedPushButton::KSMDelayedPushButton( const KGuiItem &item,
 						const char *name)
   : KPushButton( item, parent, name), pop(0), popt(0)
 {
-  connect(this, TQT_SIGNAL(pressed()), TQT_SLOT(slotPressed()));
-  connect(this, TQT_SIGNAL(released()), TQT_SLOT(slotReleased()));
+  connect(this, TQ_SIGNAL(pressed()), TQ_SLOT(slotPressed()));
+  connect(this, TQ_SIGNAL(released()), TQ_SLOT(slotReleased()));
   popt = new TQTimer(this);
-  connect(popt, TQT_SIGNAL(timeout()), TQT_SLOT(slotTimeout()));
+  connect(popt, TQ_SIGNAL(timeout()), TQ_SLOT(slotTimeout()));
 }
 
 void KSMDelayedPushButton::setPopup(TQPopupMenu *p)
@@ -1329,7 +1329,7 @@ KSMDelayedMessageBox::KSMDelayedMessageBox( TDEApplication::ShutdownType sdtype,
 	}
 	TQTimer *timer = new TQTimer( this );
 	timer->start( 1000 );
-	connect( timer, TQT_SIGNAL( timeout() ), TQT_SLOT( updateText() ) );
+	connect( timer, TQ_SIGNAL( timeout() ), TQ_SLOT( updateText() ) );
 	KDialog::centerOnScreen(this);
 }
 
@@ -1377,7 +1377,7 @@ switch ( e->key() )
 	case Key_Enter:
 	case Key_Return:
 	case Key_Space:
-	  m_pressed = TRUE;
+	  m_pressed = true;
 	  setDown(true);
 	  emit pressed();
 	  break;
@@ -1402,7 +1402,7 @@ void KSMPushButton::keyReleaseEvent( TQKeyEvent* e )
 			if ( m_pressed )
 			{
 			setDown(false);
-			m_pressed = FALSE;
+			m_pressed = false;
 			emit released();
 			emit clicked();
 			}
@@ -1447,7 +1447,7 @@ void FlatButton::keyPressEvent( TQKeyEvent* e )
 		case Key_Enter:
 		case Key_Return:
 		case Key_Space:
-		m_pressed = TRUE;
+		m_pressed = true;
 		setDown(true);
 		emit pressed();
 		break;
@@ -1472,7 +1472,7 @@ void FlatButton::keyReleaseEvent( TQKeyEvent* e )
 			if ( m_pressed )
 			{
 			setDown(false);
-			m_pressed = FALSE;
+			m_pressed = false;
 			emit released();
 			emit clicked();
 			}
