@@ -28,7 +28,7 @@
 #include <tqtextstream.h>
 #include <tdelocale.h>
 #include <kdebug.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeio/global.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
