@@ -88,7 +88,9 @@ KPamGreeter::KPamGreeter( KGreeterPluginHandler *_handler,
 	ctx( _ctx ),
 	exp( -1 ),
 	pExp( -1 ),
-	running( false )
+	running( false ),
+	userEntryLocked(false),
+	suppressInfoMsg(false)
 {
         ctx = Login;
 
@@ -109,7 +111,7 @@ KPamGreeter::KPamGreeter( KGreeterPluginHandler *_handler,
         m_themer = themer;
 
 	if (!themer)
-		layoutItem = TQT_TQLAYOUTITEM(new TQGridLayout( 0, 0, 10 ));
+		layoutItem = new TQGridLayout( 0, 0, 10 );
 
         loginLabel = 0;
         authLabel.clear();
@@ -125,10 +127,10 @@ KPamGreeter::KPamGreeter( KGreeterPluginHandler *_handler,
 		if (fixedUser.isEmpty()) {
 			loginEdit = new KLineEdit( parent );
 			loginEdit->setContextMenuEnabled( false );
-			connect( loginEdit, TQT_SIGNAL(lostFocus()), TQT_SLOT(slotLoginLostFocus()) );
-			connect( loginEdit, TQT_SIGNAL(lostFocus()), TQT_SLOT(slotActivity()) );
-			connect( loginEdit, TQT_SIGNAL(textChanged( const TQString & )), TQT_SLOT(slotActivity()) );
-			connect( loginEdit, TQT_SIGNAL(selectionChanged()), TQT_SLOT(slotActivity()) );
+			connect( loginEdit, TQ_SIGNAL(lostFocus()), TQ_SLOT(slotLoginLostFocus()) );
+			connect( loginEdit, TQ_SIGNAL(lostFocus()), TQ_SLOT(slotActivity()) );
+			connect( loginEdit, TQ_SIGNAL(textChanged( const TQString & )), TQ_SLOT(slotActivity()) );
+			connect( loginEdit, TQ_SIGNAL(selectionChanged()), TQ_SLOT(slotActivity()) );
 			if (pred) {
 				parent->setTabOrder( pred, loginEdit );
 				pred = loginEdit;
@@ -152,9 +154,9 @@ KPamGreeter::KPamGreeter( KGreeterPluginHandler *_handler,
 		else
 			passwdEdit = new TDMPasswordEdit( echoMode,
 			                                  parent );
-		connect( passwdEdit, TQT_SIGNAL(textChanged( const TQString & )),
-		         TQT_SLOT(slotActivity()) );
-		connect( passwdEdit, TQT_SIGNAL(lostFocus()), TQT_SLOT(slotActivity()) );
+		connect( passwdEdit, TQ_SIGNAL(textChanged( const TQString & )),
+		         TQ_SLOT(slotActivity()) );
+		connect( passwdEdit, TQ_SIGNAL(lostFocus()), TQ_SLOT(slotActivity()) );
 		if (pred) {
 			parent->setTabOrder( pred, passwdEdit );
 			pred = passwdEdit;
@@ -209,7 +211,7 @@ KPamGreeter::~KPamGreeter()
 		delete loginEdit;
 		return;
 	}
-	TQLayoutIterator it = TQT_TQLAYOUT(layoutItem)->iterator();
+	TQLayoutIterator it = static_cast<TQLayout*>(layoutItem)->iterator();
 	for (TQLayoutItem *itm = it.current(); itm; itm = ++it)
 		 delete itm->widget();
 	delete layoutItem;
@@ -263,6 +265,11 @@ KPamGreeter::setUser( const TQString &user )
         }
 }
 
+void KPamGreeter::lockUserEntry( const bool lock ) {
+	userEntryLocked = lock;
+	loginEdit->setEnabled(!lock);
+}
+
 void // virtual
 KPamGreeter::setPassword( const TQString &pass )
 {
@@ -279,10 +286,32 @@ KPamGreeter::setEnabled(bool enable)
 //		loginLabel->setEnabled( enable );
 		authEdit[0]->setEnabled( enable );
 		setActive( enable );
-		if (enable)
+		if (enable) {
 			authEdit[0]->setFocus();
+		}
 	}
 
+void KPamGreeter::setInfoMessageDisplay(bool enable) {
+	suppressInfoMsg = !enable;
+}
+
+void KPamGreeter::setPasswordPrompt(const TQString &prompt) {
+#if 0
+	if (passwdLabel) {
+		if (prompt != TQString::null) {
+			passwdLabel->setText(prompt);
+		}
+		else {
+			passwdLabel->setText(passwordPrompt());
+		}
+		if (grid) {
+			grid->invalidate();
+			grid->activate();
+		}
+	}
+#endif
+}
+
 void // private
 KPamGreeter::returnData()
 {
@@ -296,16 +325,16 @@ KPamGreeter::returnData()
 					  KGreeterPluginHandler::IsUser );
 		break;
 	case 1:
-		handler->gplugReturnText( authEdit[0]->password(),
+		handler->gplugReturnText( authEdit[0]->password().local8Bit(),
 					  KGreeterPluginHandler::IsPassword |
 					  KGreeterPluginHandler::IsSecret );
 		break;
 	case 2:
-		handler->gplugReturnText( authEdit[1]->password(),
+		handler->gplugReturnText( authEdit[1]->password().local8Bit(),
 					  KGreeterPluginHandler::IsSecret );
 		break;
 	default: // case 3:
-		handler->gplugReturnText( authEdit[2]->password(),
+		handler->gplugReturnText( authEdit[2]->password().local8Bit(),
 					  KGreeterPluginHandler::IsNewPassword |
 					  KGreeterPluginHandler::IsSecret );
 		break;
@@ -315,17 +344,22 @@ KPamGreeter::returnData()
 bool // virtual
 KPamGreeter::textMessage( const char *text, bool err )
 {
-    kg_debug(" ************** textMessage(%s, %d)\n", text, err);
+	kg_debug(" ************** textMessage(%s, %d)\n", text, err);
 
-    if (!authEdit.size())
-	    return false;
+	if (!authEdit.size()) {
+		return false;
+	}
 
-    if (getLayoutItem()) {
-      TQLabel* label = new TQLabel(TQString::fromUtf8(text), m_parentWidget);
-      getLayoutItem()->addWidget(label, state+1, 0, 0);
-    }
+	if (!err && suppressInfoMsg) {
+		return true;
+	}
 
-    return true;
+	if (getLayoutItem()) {
+		TQLabel* label = new TQLabel(TQString::fromUtf8(text), m_parentWidget);
+		getLayoutItem()->addWidget(label, state+1, 0, 0);
+	}
+
+	return true;
 }
 
 void // virtual
@@ -335,14 +369,15 @@ KPamGreeter::textPrompt( const char *prompt, bool echo, bool nonBlocking )
     kg_debug("state is %d, authEdit.size is %d\n", state, authEdit.size());
 
     if (state == 0 && echo) {
-        if (loginLabel)
+        if (loginLabel) {
 	    loginLabel->setText(TQString::fromUtf8(prompt));
+	}
         else if (m_themer) {
             KdmLabel *tdmlabel = static_cast<KdmLabel*>(m_themer->findNode("user-label"));
             if (tdmlabel) {
                 //userLabel->setText(TQString::fromUtf8(prompt));
                 tdmlabel->label.text = TQString::fromUtf8(prompt);
-                TQTimer::singleShot(0, tdmlabel, TQT_SLOT(update()));
+                TQTimer::singleShot(0, tdmlabel, TQ_SLOT(update()));
             }
         }
     }
@@ -360,7 +395,7 @@ KPamGreeter::textPrompt( const char *prompt, bool echo, bool nonBlocking )
                 //userLabel->setText(TQString::fromUtf8(prompt));
                 TQString str = TQString::fromUtf8(prompt);
                 tdmlabel->label.text = str;
-                TQTimer::singleShot(0, tdmlabel, TQT_SLOT(update()));
+                TQTimer::singleShot(0, tdmlabel, TQ_SLOT(update()));
             }
         }
 
@@ -370,9 +405,9 @@ KPamGreeter::textPrompt( const char *prompt, bool echo, bool nonBlocking )
 	    passwdEdit = new TDMPasswordEdit( m_parentWidget );
 	else
 	    passwdEdit = new TDMPasswordEdit( echoMode, m_parentWidget);
-	connect( passwdEdit, TQT_SIGNAL(textChanged( const TQString & )),
-		TQT_SLOT(slotActivity()) );
-	connect( passwdEdit, TQT_SIGNAL(lostFocus()), TQT_SLOT(slotActivity()) );
+	connect( passwdEdit, TQ_SIGNAL(textChanged( const TQString & )),
+		TQ_SLOT(slotActivity()) );
+	connect( passwdEdit, TQ_SIGNAL(lostFocus()), TQ_SLOT(slotActivity()) );
 	authEdit << passwdEdit;
 
 #if 1
@@ -400,7 +435,7 @@ KPamGreeter::textPrompt( const char *prompt, bool echo, bool nonBlocking )
            if (0) {
                 //userLabel->setText(TQString::fromUtf8(prompt));
                 //tdmlabel->label.text = TQString::fromUtf8(prompt);
-                //TQTimer::singleShot(0, tdmlabel, TQT_SLOT(update()));
+                //TQTimer::singleShot(0, tdmlabel, TQ_SLOT(update()));
            }
        } 
        else
@@ -598,8 +633,14 @@ KPamGreeter::clear()
 void
 KPamGreeter::setActive( bool enable )
 {
-	if (loginEdit)
-		loginEdit->setEnabled( enable );
+	if (loginEdit) {
+		if (userEntryLocked) {
+			loginEdit->setEnabled( false );
+		}
+		else {
+			loginEdit->setEnabled( enable );
+		}
+	}
 }
 
 void
@@ -667,7 +708,7 @@ create( KGreeterPluginHandler *handler, KdmThemer *themer,
 	return new KPamGreeter( handler, themer, parent, predecessor, fixedEntity, func, ctx );
 }
 
-KDE_EXPORT kgreeterplugin_info kgreeterplugin_info = {
+TDE_EXPORT kgreeterplugin_info kgreeterplugin_info = {
 	I18N_NOOP("Pam conversation plugin"), "pam",
 	kgreeterplugin_info::Local | kgreeterplugin_info::Presettable,
 	init, done, create
