@@ -33,7 +33,7 @@
 
 extern "C"
 {
-	KDE_EXPORT TQObject* allocate_config( TDEConfig* conf, TQWidget* parent )
+	TDE_EXPORT TQObject* allocate_config( TDEConfig* conf, TQWidget* parent )
 	{
 		return ( new KeramikConfig( conf, parent ) );
 	}
