@@ -15,7 +15,7 @@
 
 extern "C"
 {
-	KDE_EXPORT TQObject* allocate_config( TDEConfig* conf, TQWidget* parent )
+	TDE_EXPORT TQObject* allocate_config( TDEConfig* conf, TQWidget* parent )
 	{
 		return(new QuartzConfig(conf, parent));
 	}
